@@ -8,5 +8,8 @@ bundle exec rspec spec
 # Ensure there is no existing version
 bundle exec gem uninstall pathspec
 
+# Clear old artifacts
+rm pathspec-*.gem
+
 # Build and install!
-bundle exec gem build pathspec.gemspec && bundle exec gem install pathspec-0.2.0.gem
+bundle exec gem build pathspec.gemspec && bundle exec gem install pathspec-*.gem
