@@ -1,8 +1,9 @@
+# frozen_string_literal: true
+
 class PathSpec
   # Abstract spec
   class Spec
-    attr_reader :regex
-    attr_reader :pattern
+    attr_reader :regex, :pattern
 
     def initialize(*_); end
 
